# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [Unreleased]

nothing as of yet


## [1.1.1] - 2023-08-07

### Added

- basic test which makes sure the default sample executes without errors

### Changed

- metadata of python package as to make it more user-friendly when browsing PyPI

### Fixed

- licensing issue with default sample, as it was previously unlicensed

### Removed

- redundant default sample configuration


## [1.1.0] - 2023-08-07

### Added

- Changelog
- License

### Changed

- Output path of attachments, which are now contained in directories named 
  after their containing page


## [1.0.1] - 2023-08-07

### Added

- Sample manifest in README to give a better idea on the output


## [1.0.0] - 2023-08-07

### Added

- initial release


[unreleased]: https://bitbucket.org/victorykit/xconfluencebuilder/branch/master
[1.1.1]: https://bitbucket.org/victorykit/xconfluencebuilder/src/v1.1.1/
[1.1.0]: https://bitbucket.org/victorykit/xconfluencebuilder/src/v1.1.0/
[1.0.1]: https://bitbucket.org/victorykit/xconfluencebuilder/src/v1.0.1/
[1.0.0]: https://bitbucket.org/victorykit/xconfluencebuilder/src/v1.0.0/
